@@ -119,5 +119,8 @@ DCIM_SystemString = ('http://schemas.dell.com/wbem/wscim/1/cim-schema/2/'
 DCIM_SystemView = ('http://schemas.dell.com/wbem/wscim/1/cim-schema/2/'
                    'DCIM_SystemView')
 
+DCIM_VideoView = ('http://schemas.dell.com/wbem/wscim/1/cim-schema/2/'
+                  'DCIM_VideoView')
+
 DCIM_VirtualDiskView = ('http://schemas.dell.com/wbem/wscim/1/cim-schema/2/'
                         'DCIM_VirtualDiskView')
